@@ -2,7 +2,7 @@
 
 package Language::Farnsworth;
 
-our $VERSION = "0.7.2";
+our $VERSION = "0.7.5";
 
 use strict;
 use warnings;
@@ -16,8 +16,6 @@ use Language::Farnsworth::Variables;
 use Language::Farnsworth::Output;
 use Math::Pari;
 
-use Carp qw(croak);
-
 use Data::Dumper;
 
 sub new
@@ -28,7 +26,7 @@ sub new
 	my @modules = @_; #i get passed a list of modules to use for standard stuff;
 
 	Math::Pari::setprecision(100); #both of these need to be user configurable!
-	Math::Pari::allocatemem(400_000_00);
+	Math::Pari::allocatemem(40_000_000);
 
 	if (@modules < 1)
 	{
@@ -43,7 +41,7 @@ sub new
 	{
 		local $@;
 		eval 'use Language::Farnsworth::'.$a.'; Language::Farnsworth::'.$a.'::init($self->{eval});';
-		#die $@ if $@;
+		die $@ if $@;
 		#print "-------FAILED? $a\n";
 		#print $@;
 		#print "\n";
@@ -110,7 +108,7 @@ sub runFile
 1;
 __END__
 
-# Below is stub documentation for your module. You'd better edit it!
+=encoding utf8
 
 =head1 NAME
 
@@ -118,22 +116,20 @@ Language::Farnsworth - A Turing Complete Language for Mathematics
 
 =head1 SYNOPSIS
 
-  use Language::Farnsworth;
-  
-  my $hubert = Language::Farnsworth->new();
-
-  my $result = $hubert->runString("10 km -> miles");
-
-  my $result = $hubert->runFile("file.frns");
-
-  print $result;
+	use Language::Farnsworth;
+	
+	my $hubert = Language::Farnsworth->new();
+	
+	my $result = $hubert->runString("10 km -> miles");
+	my $result = $hubert->runFile("file.frns");
+	
+	print $result;
 
 =head1 DESCRIPTION
 
-THIS IS A BETA RELEASE, perpetually so! There are typos in the error messages and in the POD.  There are also probably plenty of bugs.  It is being released early because there have been a number of people who have shown interest in having it released.  Not every feature is documented yet and a future release will have that cleaned up along with some of the hairier parts of the internal API.
-Language::Farnsworth is a programming language originally inspired by Frink (see http://futureboy.homeip.net/frinkdocs/ ).
-However due to creative during the creation of it, the syntax has changed significantly and the capabilities are also different.
-Some things Language::Farnsworth can do a little better than Frink, other areas Language::Farnsworth lacks.
+THIS IS A BETA RELEASE, perpetually so! There are typos in the error messages and in the POD.  
+There are also probably plenty of bugs.  While it is not ready for production use, it is most certainly usable as a toy and to see a pure interpreter written in perl.
+Not every feature is documented yet (This 0.7.x series will be striving to fix that) and a future release will fix the hairier parts of the internal API (scheduled for 0.8.x).
 
 =head2 PREREQUISITS
 
@@ -240,15 +236,24 @@ Objects!
 
 =back
 
+=head1 HISTORY
+
+Language::Farnsworth is a programming language originally inspired by Frink (see http://futureboy.homeip.net/frinkdocs/ ).
+However due to creative during the creation of it, the syntax has changed significantly and the capabilities are also different.
+Some things Language::Farnsworth can do a little better than Frink, other areas Language::Farnsworth lacks.  
+And while ostensibly the language may appear to be named in a similar vein after another cartoon professor that brings good news to everyone,
+it is in fact named after the famous physicist Philo T. Farnsworth.
+
 =head1 SEE ALSO
 
 L<Language::Farnsworth::Docs::Syntax> L<Language::Farnsworth::Docs::Functions>
 
 Please use the bug tracker available from CPAN to submit bugs.
+There are also things to be 
 
 =head1 AUTHOR
 
-Ryan Voots E<lt>simcop@cpan.orgE<gt>
+Ryan Voots E<lt>L<simcop@cpan.org>E<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
